@@ -130,7 +130,11 @@ class _MapdlCore(_MapdlCommands):
             self.open_apdl_log(filename, mode=log_apdl)
 
         self._post = PostProcessing(self)
-        self._distributed = '-smp' not in start_parm.get('additional_switches', '')
+
+    @property
+    def _distributed(self):
+        """Is a distributed analysis"""
+        return '-smp' not in self._start_parm.get('additional_switches', '')
 
     @property
     def post_processing(self):
@@ -610,10 +614,11 @@ class _MapdlCore(_MapdlCommands):
         if isinstance(knum, bool):
             knum = int(knum)
 
+        self._enable_interactive_plotting()
         return super().nplot(knum)
 
     def vplot(self, nv1="", nv2="", ninc="", degen="", scale="",
-              vtk=None, quality=7, show_area_numbering=False,
+              vtk=None, quality=4, show_area_numbering=False,
               show_line_numbering=False,
               color_areas=False, show_lines=True,
               **kwargs):
@@ -672,10 +677,11 @@ class _MapdlCore(_MapdlCommands):
                        show_lines=show_lines, **kwargs)
             self.cmsel('S', cm_name, 'AREA')
         else:
+            self._enable_interactive_plotting()
             return super().vplot(nv1=nv1, nv2=nv2, ninc=ninc)
 
     def aplot(self, na1="", na2="", ninc="", degen="", scale="",
-              vtk=None, quality=7, show_area_numbering=False,
+              vtk=None, quality=4, show_area_numbering=False,
               show_line_numbering=False, color_areas=False,
               show_lines=False, **kwargs):
         """APDL Command: APLOT
@@ -791,6 +797,7 @@ class _MapdlCore(_MapdlCommands):
                                    labels, **kwargs)
 
         else:
+            self._enable_interactive_plotting()
             return super().aplot(na1=na1, na2=na2, ninc=ninc)
 
     @supress_logging
@@ -927,6 +934,7 @@ class _MapdlCore(_MapdlCommands):
                                    **kwargs)
 
         # otherwise, use MAPDL plotter
+        self._enable_interactive_plotting()
         return super().eplot()
 
     def lplot(self, nl1="", nl2="", ninc="", vtk=None,
@@ -996,6 +1004,7 @@ class _MapdlCore(_MapdlCommands):
                                    labels,
                                    **kwargs)
         else:
+            self._enable_interactive_plotting()
             return super().lplot(nl1=nl1, nl2=nl2, ninc=ninc)
 
     def kplot(self, np1="", np2="", ninc="", lab="", vtk=None,
@@ -1050,6 +1059,7 @@ class _MapdlCore(_MapdlCommands):
                                    labels, **kwargs)
 
         # otherwise, use the legacy plotter
+        self._enable_interactive_plotting()
         return super().kplot(np1=np1, np2=np2, ninc=ninc, lab=lab)
 
     @property
@@ -1937,9 +1947,7 @@ class _MapdlCore(_MapdlCommands):
 
     def __del__(self):  # pragma: no cover
         """Clean up when complete"""
-        self._log.debug('Collecting...')
         if self._cleanup:
-            self._log.debug('self._cleanup == True')
             try:
                 self.exit()
             except Exception as e:
